Client

Trait Client 

pub trait Client {
    // Required methods
    fn new(account_id: AccountID) -> Self;
    fn account_id(&self) -> AccountID;
}
The trait that clients of a service must implement.

Required Methods

fn new(account_id: AccountID) -> Self

Create a new client with the given account ID.

fn account_id(&self) -> AccountID

Get the address of the account this client is associated with.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors