pub trait Client {
// Required methods
fn new(account_id: AccountID) -> Self;
fn account_id(&self) -> AccountID;
}Expand description
The trait that clients of a service must implement.
Required Methods
Sourcefn account_id(&self) -> AccountID
fn account_id(&self) -> AccountID
Get the address of the account this client is associated with.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.