Resource module.
Structs
- Resource
Scope - The resource scope.
Enums
- Initialization
Error - An error that occurs during resource initialization.
Traits
- Resources
- An account or module handler’s resources. This is usually derived by the state management framework.
- State
Object Resource - A resource is anything that an account or module can use to store its own state or interact with other accounts and modules.